import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "components"

import Artix.Core
import Artix.Gui
import Artix.Handlers

/**
 * @brief Окно сообщения
 */
ModalDialog {
    id: dialog

    property int messageType: params.type
    property DialogEventFilter eventFilter: DialogEventFilter {
        onOk: handler.sendAnswer()
        onCancel: handler.sendAnswer()
    }

    implicitWidth: image.visible ? Math.max(defaultWidth, image.width + leftPadding + rightPadding) : defaultWidth

    contentItem: ColumnLayout {
        spacing: 24
        Image {
            id: image
            Layout.alignment: Qt.AlignHCenter
            Layout.maximumWidth: Style.resolution.width * 0.75
            Layout.preferredWidth: paintedWidth
            Layout.preferredHeight: 72
            fillMode: Image.PreserveAspectFit
            Component.onCompleted: mainWindow.scaleImage(this)
            source: {
                if (dialog.messageType === DialogEnum.Error)
                    return Style.parameter("icon.dialog.error")
                if (dialog.messageType === DialogEnum.Warning)
                    return Style.parameter("icon.dialog.warning")
                return Style.parameter("icon.dialog.info")
            }
        }
        BasicLabel {
            Layout.alignment: Qt.AlignHCenter
            Layout.preferredWidth: parent.width
            horizontalAlignment: Text.AlignHCenter
            Style.class: "messageBoxMessage"
            Tr { tr: params.message }
        }
        BasicButton {
            id: okButton
            Layout.alignment: Qt.AlignHCenter
            Layout.preferredWidth: 200
            Layout.preferredHeight: 56
            textLayout.alignment: Qt.AlignVCenter | Qt.AlignHCenter
            Style.class: "messageBoxOk"
            visible: !params.hideButton
            Tr { code: "okButton"; defaultMessage: "OK" }
            DialogHandler { id: handler }
            onClicked: handler.sendAnswer()
        }
    }
}
