import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "components"

import Artix.Core
import Artix.Gui
import Artix.Handlers

/**
 * @brief Диалог прогресса
 */
ModalDialog {
    id: dialog
    readonly property bool isProgress: true

    contentItem: ColumnLayout {
        spacing: 0
        BasicLabel {
            Layout.alignment: Qt.AlignHCenter
            Layout.preferredWidth: parent.width
            horizontalAlignment: Text.AlignHCenter
            Style.class: "progressBoxTitle"
            Tr { tr: params.useTerminal ? params.message : params.title }
        }

        Item { visible: message.visible; Layout.preferredHeight: 16 }
        BasicLabel {
            id: message
            Layout.preferredWidth: parent.width
            horizontalAlignment: Text.AlignHCenter
            Style.class: "progressBoxMessage"
            visible: text.length > 0
            Tr { id: messageTr; tr: progressState.status }
        }

        Item { visible: progressBar.visible; Layout.preferredHeight: 8 }
        ProgressBar {
            id: progressBar
            Layout.preferredWidth: 340
            Layout.preferredHeight: 8
            Layout.alignment: Qt.AlignHCenter
            to: 100
            value: progressState.progress
            visible: !params.useTerminal
            contentItem: Item {
                property real progressWidth: width * parent.visualPosition
                Rectangle {
                    y: 0
                    x: 0
                    height: parent.height
                    width: parent.progressWidth
                    color: Style.parameter("color.green")
                    radius: 20
                }
            }
            background: Rectangle {
                color: Style.parameter("color.graySoft")
                radius: 20
            }
        }

        Item { Layout.preferredHeight: 24; visible: cancelButton.visible }
        BasicButton {
            id: cancelButton
            Layout.preferredWidth: 200
            Layout.preferredHeight: 56
            Layout.alignment: Qt.AlignHCenter
            textLayout.alignment: Qt.AlignHCenter | Qt.AlignVCenter
            Style.class: "progressBoxCancel"
            visible: params.showCancelButton ? params.showCancelButton : false
            Tr { code: "dialogProcessCancelButton"; defaultMessage: "Отмена" }
            onClicked: {
                if (handler.cancel()) {
                    messageTr.tr = handler.cancelStatus
                    cancelButton.enabled = false
                }
            }
        }
    }

    Connections {
        target: progressState
        function onCurrentStatusChanged(message) { messageTr.tr = message }
        function onCurrentProgressChanged(progress) { progressBar.value = progress }
    }

    ProgressBoxHandler {
        id: handler
        Component.onCompleted: handler.setCancelFunction(params.onCancelHandler)
    }
}
