import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "components"
import "./view"

import Artix.Core
import Artix.Gui
import Artix.Handlers

/**
 * @brief Окно отображения QR-кода
 */
FullscreenDialog {
    id: dialog

    property bool showQrCode: true
    withBottomPanel: params.showBottomPanel ?? true

    Component {
        id: scanQrCodeClient
        Rectangle {
            color: Style.parameter("color.modalBackground")
            ColumnLayout {
                anchors.centerIn: parent
                spacing: 0
                BasicLabel {
                    Layout.alignment: Qt.AlignHCenter
                    Style.class: "scanQrCodeTitle"
                    Tr { code: "scanQrCodeFormTitle"; defaultMessage: "Оплата по QR-коду" }
                }
                Item {
                    Layout.preferredHeight: 16
                }
                BasicLabel {
                    Layout.alignment: Qt.AlignHCenter
                    Style.class: "scanQrCodeMessage"
                    Tr { code: "scanQrCodeFormMessage"; defaultMessage: "Отсканируйте при помощи телефона" }
                }
                Item {
                    Layout.preferredHeight: 96
                }
                Image {
                    Layout.alignment: Qt.AlignHCenter
                    Layout.preferredWidth: 296
                    Layout.preferredHeight: 296
                    source: "data:image/png;base64," + Utils.generateQr(params.qrCode, 296)
                }
                Item {
                    Layout.preferredHeight: 116
                }
                BasicLabel {
                    Layout.alignment: Qt.AlignHCenter
                    Style.class: "scanQrCodeHint"
                    Tr {
                        code: "scanQrCodeFormHint"
                        defaultMessage: "Операция будет автоматически отменена через %1 сек."
                        args: [ timer.secondsLeft ]
                    }
                }
            }
        }
    }
    Component {
        id: scanQrCodeCashier
        Rectangle {
            color: Style.parameter("color.modalBackground")
            ColumnLayout {
                anchors.centerIn: parent
                BasicLabel {
                    Layout.alignment: Qt.AlignHCenter
                    Layout.preferredWidth: 302
                    maximumLineCount: 9
                    horizontalAlignment: Text.AlignHCenter
                    Style.class: "scanQrCodeCashierMessage"
                    Tr { code: "scanQrCodeFormCashierMessage"; defaultMessage: "Открыто окно оплаты\nпо QR-коду" }
                }
                Item {
                    Layout.preferredHeight: 40
                }
                BasicLabel {
                    Layout.alignment: Qt.AlignHCenter
                    Layout.preferredWidth: 302
                    maximumLineCount: 4
                    horizontalAlignment: Text.AlignHCenter
                    Style.class: "scanQrCodeCashierHint"
                    Tr {
                        code: "scanQrCodeFormCashierHint"
                        defaultMessage: "Отмена операции\nчерез %1 сек."
                        args: [ timer.secondsLeft ]
                    }
                }
            }
        }
    }
    RowLayout {
        anchors.fill: parent
        spacing: 0

        Loader {
            id: scanQrCode
            sourceComponent: showQrCode ? scanQrCodeClient : scanQrCodeCashier
            Layout.fillHeight: true
            Layout.preferredWidth: parent.width - sidePanel.width
        }
        Item {
            id: sidePanel
            visible: params.showSidePanel ?? true
            Layout.fillHeight: true
            Layout.preferredWidth: showQrCode ? Math.floor((screenWidth * 0.1 + 201) / 8) * 8 : Math.floor((screenWidth * 0.19 + 374) / 8) * 8
            TopPanel {
                id: topPanel
                anchors { left: parent.left; top: parent.top; right: parent.right }
                anchors.leftMargin: 24
                hideUserName: showQrCode
            }
            Item {
                anchors { left: parent.left; top: topPanel.bottom; right: parent.right }
                anchors.topMargin: 32
                visible: !showQrCode
                Layout.fillWidth: true
                Layout.preferredHeight: 48
                RowLayout {
                    anchors.fill: parent
                    BasicLabel {
                        id: title
                        anchors { left: parent.left }
                        anchors.leftMargin: 24
                        anchors.bottomMargin: 0
                        Style.class: "scanQrCodeTotalTitle"
                        Tr { code: "scanQrCodeFormPayableSum"; defaultMessage: "К оплате" }
                    }
                    BasicLabel {
                        anchors { right: parent.right }
                        anchors.rightMargin: 24
                        anchors.baseline: title.baseline
                        Style.class: "scanQrCodeTotalValue"
                        text: Utils.formatMoneyItem(params.amount * 0.01)
                        horizontalAlignment: Text.AlignRight
                    }
                }
            }
            BasicButton {
                Style.class: "scanQrCodeCancel"
                anchors {
                    right: parent.right
                    rightMargin: 24
                    bottom: parent.bottom
                    bottomMargin: 24
                }
                width: 256; height: showQrCode ? 68 : 144
                Tr { code: "scanQrCodeFormCancel"; defaultMessage: "Отмена" }
                onClicked: {
                    let args = {}
                    args["data"] = false
                    handler.sendAnswer(args)
                }
            }
        }
    }

    DialogHandler { id: handler }

    Timer {
        id: timer
        property int secondsLeft: params.timeout
        interval: 1000
        running: secondsLeft > 0
        repeat: true
        onTriggered: --secondsLeft
    }
}
