import QtQuick
import QtQuick.Controls
import QtQuick.Layouts
import QtWebEngine

import "components"
import "view"

import Artix.Handlers
import Artix.Core
import Artix.Gui

/**
 * @brief Форма web-браузера
 */
FullscreenDialog {
    id: root
    property BrowserEventFilter eventFilter: BrowserEventFilter {
        blockAllKeyEvents: false
        onExit: handler.emitAction("DIALOG_WEB_BROWSER")
    }

    header: Item {
        height: 72
        Item {
            anchors { top: parent.top; bottom: parent.bottom; left: parent.left }
            width: parent.width - topPanel.iconsWidth - 16
            RowLayout {
                x: 16; width: parent.width - x; height: parent.height; spacing: 24
                // Закрытие диалога
                BasicButton {
                    Style.class: "webBrowserExit"
                    Layout.preferredWidth: 56; Layout.preferredHeight: 56; radius: 28
                    Layout.alignment: Qt.AlignVCenter
                    icon: Style.parameter("icon.browser.exit")
                    onClicked: handler.emitAction("DIALOG_WEB_BROWSER")
                }
                // Перейти на предыдущую страницу
                BasicButton {
                    Style.class: "webBrowserCommon"
                    Layout.preferredWidth: 56; Layout.preferredHeight: 56; radius: 28
                    Layout.alignment: Qt.AlignVCenter
                    enabled: webView.canGoBack
                    icon: webView.canGoBack ? Style.parameter("icon.browser.back")
                                            : Style.parameter("icon.browser.backDisabled")
                    onClicked: webView.goBack()
                }
                // Перейти на следующую страницу
                BasicButton {
                    Style.class: "webBrowserCommon"
                    Layout.preferredWidth: 56; Layout.preferredHeight: 56; radius: 28
                    Layout.alignment: Qt.AlignVCenter
                    enabled: webView.canGoForward
                    icon: webView.canGoForward ? Style.parameter("icon.browser.forward")
                                               : Style.parameter("icon.browser.forwardDisabled")
                    onClicked: webView.goForward()
                }
                // Обновить страницу или остановить загрузку страницы
                BasicButton {
                    Style.class: "webBrowserCommon"
                    Layout.preferredWidth: 56; Layout.preferredHeight: 56; radius: 28
                    Layout.alignment: Qt.AlignVCenter
                    icon: webView.loading ? Style.parameter("icon.browser.stop")
                                          : Style.parameter("icon.browser.reload")
                    onClicked: {
                        if (webView.loading)
                            webView.stop()
                        else
                            webView.reload()
                    }
                }
                // Заголовок страницы
                BasicLabel {
                    Style.class: "webBrowserTitle"
                    Layout.fillWidth: true
                    Layout.preferredHeight: 24
                    Layout.alignment: Qt.AlignVCenter
                    text: webView.title
                    elide: Label.ElideRight
                }
            }
        }
        TopPanel {
            id: topPanel
            anchors { top: parent.top; bottom: parent.bottom; right: parent.right }
            hideUserName: true
        }
        // Прогресс загрузки страницы
        ProgressBar {
            anchors.top: parent.bottom
            width: parent.width; height: 2
            to: 100
            value: webView.loadProgress
            visible: webView.loading
            contentItem: Item {
                property real progressWidth: width * parent.visualPosition
                Rectangle {
                    x: 0; y: 0
                    width: parent.progressWidth; height: parent.height
                    color: Style.parameter("color.blueDark")
                }
            }
            background: null
        }
    }

    contentItem: WebEngineView {
        id: webView
        url: params.url
        settings.defaultTextEncoding: params.codePage
    }

    DialogHandler { id: handler }

    // Всплывающая клавиатура
    PopupKeyboard {
        id: popupKeyboard
        keyboard {
            layoutType: params.showDigitalKeyboard ? "input_digits" : "main"
            onEnter: handler.emitKey(Qt.Key_Enter)
        }
        Connections {
            target: Qt.inputMethod
            function onVisibleChanged() {
                if (!params.showKeyboard)
                    return

                if (Qt.inputMethod.visible)
                    popupKeyboard.open()
                else
                    popupKeyboard.close()
            }
        }
    }

    LockDelay { enabled: params.lockDelay }
}
