import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import Artix.Gui

/**
 * @brief Кнопка
 */
Control {
    id: root
    Style.type: "button"
    Style.class: "default"
    padding: 12

    property alias text: textContent.text
    property alias radius: background.radius
    property alias color: background.color
    property alias icon: imageContent.source
    property alias textOpacity: textContent.opacity
    property bool down: pressed
    property bool pressed: tapHandler.pressed
    property LayoutProperty textLayout: LayoutProperty {
        alignment: Qt.AlignLeft | Qt.AlignBottom
    }
    property LayoutProperty iconLayout: LayoutProperty {
        alignment: textContent.visible ? textLayout.alignment
                                       : (Qt.AlignVCenter | Qt.AlignHCenter)
    }
    property alias verticalAlignment: textContent.verticalAlignment
    property alias horizontalAlignment: textContent.horizontalAlignment
    signal clicked()

    contentItem: RowLayout {
        Text {
            Layout.alignment: textLayout.alignment
            Layout.preferredWidth: textLayout.preferredWidth
            Layout.preferredHeight: textLayout.preferredHeight
            Layout.fillWidth: textLayout.fillWidth
            Layout.fillHeight: textLayout.fillHeight
            id: textContent
            font: root.Style.text.font
            color: root.Style.text.color
            visible: text.length > 0
            wrapMode: Text.Wrap
            elide: Text.ElideRight
        }
        Image {
            Layout.alignment: iconLayout.alignment
            Layout.preferredWidth: iconLayout.preferredWidth
            Layout.preferredHeight: iconLayout.preferredHeight
            Layout.fillWidth: iconLayout.fillWidth
            Layout.fillHeight: iconLayout.fillHeight
            id: imageContent
            fillMode: Image.PreserveAspectFit
            visible: false
            onSourceChanged: visible = true
        }
    }

    background: Rectangle {
        id: background
        color: root.Style.background.color
        border.color: root.Style.background.border.color
        border.width: root.Style.background.border.width
        radius: root.Style.background.radius

        Behavior on color { ColorAnimation { duration: 100 }}
    }

    TapHandler {
        id: tapHandler
        onTapped: clicked()
    }
}
