import QtQuick
import QtQuick.Controls

import Artix.Gui
import Artix.Core

/**
 * @brief Базовое отображения для диалогов
 */
Dialog {
    id: dialog

    property alias radius: background.radius
    property alias color: background.color
    property bool withBottomPanel: true // отображать нижнюю панель
    property EventFilterConnector eventFilterConnector: null

    onEventFilterConnectorChanged: {
        this?.onEventFilterChanged?.connect(() => updateEventFilter())
        this?.onEventReceiverChanged?.connect(() => updateEventFilter())
        updateEventFilter()
    }
    // Обновить фильтр формы и ресивер ввода для диалога
    function updateEventFilter() {
        let eventFilter = this?.eventFilter
        let eventReceiver = this?.eventReceiver
        eventFilterConnector.update(eventFilter, eventReceiver)
    }

    parent: mainWindow.contentItem
    padding: 0
    x: 0; y: 0
    modal: true
    closePolicy: Popup.NoAutoClose
    Overlay.modal: Rectangle {
        color: Style.parameter("color.modalShading")
        anchors {
            fill: parent
            bottomMargin: withBottomPanel ? mainWindow.footer.height : 0
        }
    }
    Overlay.modeless: null
    background: Rectangle {
        id: background
        color: Style.parameter("color.background")
    }
    scale: mainWindow.scaleFactor
    transformOrigin: Item.TopLeft
    enter: null
    exit: null
}
