import QtQuick

import Artix.Gui

/**
 * @brief Базовое представление бокового диалога
 */
BasicDialog {
    id: control
    x: primaryScreen.geometry.width + implicitWidth * (scale - 1)
    padding: 24
    implicitWidth: 520
    implicitHeight: Style.resolution.height - mainWindow.footer.height
    width: implicitWidth
    height: implicitHeight
    color: Style.parameter("color.modalBackground")
    transformOrigin: Item.TopRight
    enter: Transition {
        SmoothedAnimation {
            id: enterAnimation
            property: "x"
            velocity: 1500 * scale
            to: primaryScreen.geometry.width - control.implicitWidth
        }
    }
    exit: Transition {
        SmoothedAnimation {
            id: exitAnimation
            property: "x"
            velocity: 1500 * scale
            to: primaryScreen.geometry.width + (implicitWidth * scale - implicitWidth)
        }
    }

    Connections {
        target: primaryScreen
        function onGeometryChanged(geometry) {
            if (control.opened) {
                // Костыль для повторного отображения диалога при изменении разрешения экрана.
                // Без этого при увеличении разрешения по высоте верстка ломается.
                if (control.hasOwnProperty("destroyOnClosed"))
                    control.destroyOnClosed = false
                let storeDuration = exitAnimation.duration
                exitAnimation.duration = 0
                control.close()
                exitAnimation.duration = storeDuration
                storeDuration = enterAnimation.duration
                enterAnimation.duration = 0
                control.open()
                enterAnimation.duration = storeDuration
                if (control.hasOwnProperty("destroyOnClosed"))
                    control.destroyOnClosed = true
            }
        }
    }
}
