import QtQuick
import QtQuick.Controls
import QtQuick.Layouts

import "../components"

import Artix.Core
import Artix.Gui
import Artix.Models

/**
 * @brief Обалсть уведомлений (шторка)
 */
Drawer {
    modal: true
    clip: true
    dragMargin: 72.0
    edge: Qt.TopEdge
    height: mainContent.implicitHeight + notificationList.height + 56

    RowLayout {
        id: mainContent
        anchors {
            top: parent.top; left: parent.left; right: parent.right
            margins: 24; bottomMargin: 0
        }
        ColumnLayout {
            BasicLabel {
                Style.class: "notificationAreaCash"
                Tr { code: "cashCode"; defaultMessage: "Касса %1"; args: [ Session.cashCode ] }
            }
            Item { Layout.preferredHeight: 16 }
            RowLayout {
                spacing: 3
                BasicLabel {
                    Style.class: "notificationAreaIpText"
                    Tr { code: "notificationAreaIp"; defaultMessage: "IP кассы" }
                }
                BasicLabel {
                    Style.class: "notificationAreaIpValue"
                    text: SystemInfo.ipAddress()
                }
            }
            Item { Layout.preferredHeight: 40; visible: icons.visible }
            GridLayout {
                id: icons
                rowSpacing: 16
                columnSpacing: 16
                rows: 2
                flow: GridLayout.TopToBottom
                Repeater {
                    model: SystemIndicatorModel {}
                    delegate: RowLayout {
                        spacing: 16
                        Image {
                            Layout.alignment: Qt.AlignVCenter
                            Layout.preferredHeight: 40
                            Layout.preferredWidth: 40
                            source: Style.parameter(model.icon, model.icon)
                            fillMode: Image.PreserveAspectFit
                            Component.onCompleted: mainWindow.scaleImage(this)
                        }
                        ColumnLayout {
                            spacing: 1
                            BasicLabel {
                                Style.class: "notificationAreaIconHeader"
                                text: model.title
                            }
                            BasicLabel {
                                Style.class: {
                                    if (model.type === SystemIndicatorModel.Failed)
                                        return "notificationAreaIconDescriptionFailed"
                                    return "notificationAreaIconDescription"
                                }
                                text: model.desc
                            }
                        }
                    }
                }
            }
            Item { Layout.preferredHeight: 32; visible: upload.visible }
            RowLayout {
                id: upload
                spacing: 3
                visible: false
                BasicLabel {
                    Style.class: "notificationAreaUploadText"
                    Tr { code: "notificationAreaUpload"; defaultMessage: "Загрузка справочников" }
                }
                BasicLabel {
                    id: uploadPercent
                    Style.class: "notificationAreaUploadValue"
                    text: "100%"
                }
            }
        }
        ColumnLayout {
            Layout.alignment: Qt.AlignRight | Qt.AlignBottom
            Image {
                Layout.alignment: Qt.AlignRight
                height: 56
                width: 76
                fillMode: Image.PreserveAspectFit
                source: Style.parameter("icon.artixLogo")
                Component.onCompleted: mainWindow.scaleImage(this)
            }
            BasicLabel {
                Layout.alignment: Qt.AlignRight
                Style.class: "notificationAreaVersion"
                Tr {
                    code: "notificationAreaVersion"
                    defaultMessage: "ПО Artix POS (версия %1)"
                    args: [ Session.versionInfo.version ]
                }
                horizontalAlignment: Label.AlignRight
            }
            BasicLabel {
                Layout.alignment: Qt.AlignRight
                Style.class: "notificationAreaLicense"
                Tr {
                    code: "notificationAreaLicense"
                    defaultMessage: "лицензия действует\nдо %1"
                    args: [ SystemInfo.licenseExpireDate() ]
                }
                horizontalAlignment: Label.AlignRight
            }
        }
    }
    // Список оповещений
    ListView {
        id: notificationList
        anchors { top: mainContent.bottom; left: parent.left; right: parent.right; topMargin: 32}
        interactive: false
        spacing: 1
        width: parent.width
        readonly property real delegateHeight: 50
        height: delegateHeight * count + spacing * (count - 1)

        // При масштабировании, списки могут отображаться с артефактами.
        // Рендерим с мультисемплированием в нужном разрешении. Не знаю за счет чего, но проблему это решило.
        layer {
            enabled: mainWindow.multisampling
            samples: 2
            textureSize: Qt.size(width * mainWindow.scaleFactor, height * mainWindow.scaleFactor)
        }

        delegate: GroupBox {
            id: notificationDelegate
            Style.class: type === Notification.Info ? "notificationAreaDelegateInfo"
                                                    : "notificationAreaDelegateError"
            width: notificationList.width
            height: notificationList.delegateHeight
            interactive: false
            padding: 12
            contentItem: Item {
                id: notificationDelegateContent
                RowLayout {
                    anchors.centerIn: parent
                    height: parent.height
                    spacing: 12
                    Image {
                        id: notificationIcon
                        Layout.preferredWidth: 24
                        Layout.preferredHeight: 24
                        Layout.alignment: Qt.AlignVCenter
                        fillMode: Image.PreserveAspectFit
                        source: Style.parameter("icon.notificationWarning")
                        visible: type === Notification.Error
                        Component.onCompleted: mainWindow.scaleImage(this)
                    }
                    BasicLabel {
                        Style.class: "notificationAreaDelegate"
                        Layout.fillHeight: true
                        Layout.maximumWidth: notificationDelegateContent.width - (notificationIcon.visible ? notificationIcon.width + 12 : 0)
                        verticalAlignment: Label.AlignVCenter
                        Tr { tr: message }
                        elide: Label.ElideRight
                    }
                }
            }
        }
        model: NotificationModel {}
    }

    Connections {
        target: UploadWatcher
        function onActivated(state) {
            upload.visible = state
        }
        function onProgressChanged(progress) {
            uploadPercent.text = progress + "%"
        }
    }

    background: Rectangle {
        color: Style.parameter("color.modalBackground")
    }
    Overlay.modal: Rectangle { color: Style.parameter("color.modalShading") }
}
