import QtQuick
import QtQuick.Controls
import QtQuick.Layouts
import QtQuick.Shapes

import "../../components"
import Artix.Gui
import Artix.Core

/**
 * @brief Делегат купона в списке позиций
 */
PositionDelegate {
    property var dateBeg: object.dateBeg.toLocaleDateString(Qt.locale("en_US"), "dd.MM.yy")
    property var dateEnd: object.dateEnd.toLocaleDateString(Qt.locale("en_US"), "dd.MM.yy")
    height: (selected ? contentItem.implicitHeight : couponCommonContent.implicitHeight) + topPadding + bottomPadding
    contentItem: ColumnLayout {
        RowLayout {
            id: couponCommonContent
            BasicLabel {
                Layout.fillWidth: true
                Style.class: "couponDelegateName"
                Tr { code: "positionCoupon"; defaultMessage: "Купон %1"; args: [ object.number ] }
                elide: Text.ElideRight
            }
            Item { Layout.preferredWidth: 12 }
            Image {
                Layout.preferredWidth: 24
                Layout.preferredHeight: 24
                source: Style.parameter("icon.position.coupon")
                Component.onCompleted: mainWindow.scaleImage(this)
            }
        }
        ColumnLayout {
            opacity: selected ? 1 : 0
            spacing: 24
            RowLayout {
                spacing: 24
                ColumnLayout {
                    Layout.alignment: Qt.AlignTop
                    BasicLabel {
                        Layout.preferredWidth: 172
                        Style.class: "couponDelegateDateTitle"
                        Tr { code: "positionCouponValidityDate"; defaultMessage: "Действует" }
                    }
                    BasicLabel {
                        Layout.preferredWidth: 172
                        Style.class: "couponDelegateDateValue"
                        property string validityDate
                        Tr on validityDate {
                            code: "positionCouponValidityDateValue";
                            defaultMessage: "с %1 - по %2"
                            args: [ dateBeg, dateEnd ]
                        }
                        text: dateBeg.length > 0  || dateEnd.length > 0 ? validityDate : "-"
                    }
                }
                Line {
                    Layout.fillHeight: true
                    strokeStyle: ShapePath.DashLine
                    dashPattern: [3, 4]
                    color: Style.parameter("color.gray")
                    direction: LineDirection.Vertical
                }
                ColumnLayout {
                    Layout.alignment: Qt.AlignTop
                    BasicLabel {
                        Layout.fillWidth: true
                        Style.class: "couponDelegateCampaignTitle"
                        Tr { code: "positionCouponCampaign"; defaultMessage: "Условие" }
                    }
                    BasicLabel {
                        Layout.fillWidth: true
                        Style.class: "couponDelegateCampaignName"
                        text: object.campaignName.length > 0 ? object.campaignName : " - "
                    }
                }
            }
            BasicButton {
                Layout.preferredWidth: 232
                Layout.preferredHeight: 56
                Layout.alignment: Qt.AlignHCenter
                Style.class: "positionStorno"
                textLayout.alignment: Qt.AlignVCenter | Qt.AlignHCenter
                Tr { code: "positionStorno"; defaultMessage: "Удалить" }
                onClicked: storno(position)
            }
            Behavior on opacity { OpacityAnimator { duration: 500 } }
        }
    }
}
