import QtQuick
import QtQuick.Controls
import QtQuick.Layouts
import QtQuick.Shapes
import Qt5Compat.GraphicalEffects

import "../../components"
import Artix.Gui
import Artix.Core

/**
 * @brief Стилизованный делегат карты в списке позиций
 */
PositionDelegate {
    Style.class: "styledCardDelegate"
    height: contentItem.implicitHeight + topPadding + bottomPadding
    down: false
    function handleClick() {}
    contentItem: RowLayout {
        spacing: 24
        Control {
            Layout.preferredHeight: styledCard.height
            Layout.preferredWidth: styledCard.width
            // Компонент для "стилизованного" отображения информации о карте в виде подложки с фоновым изображением и тенью
            GroupBox {
                id: styledCard
                Style.class: "styledCardInfo"
                Layout.alignment: Qt.AlignTop
                padding: 16
                height: 140
                property bool showStatus: object.extendedOptions?.["loyaltyStatus"]?.length > 0

                background: Rectangle {
                    anchors.fill: parent
                    color: styledCard.Style.background.color
                    border.color: styledCard.Style.background.border.color
                    border.width: styledCard.Style.background.border.width
                    radius: styledCard.Style.background.radius
                    // Маска, чтобы фоновое изображение корректно обрезалось на границах виджета
                    layer {
                        enabled: true
                        effect: OpacityMask {
                            maskSource: Rectangle {
                                anchors.centerIn: parent
                                width: styledCard.width
                                height: styledCard.height
                                radius: styledCard.Style.background.radius
                            }
                        }
                    }
                    // Фоновое изображение и его позиционирование
                    GroupBox {
                        id: backgroundImage
                        Style.class: "styledCardInfoBackgroundImage"
                        contentItem: ColumnLayout {
                            Image {
                                Layout.topMargin: backgroundImage.Style.layout.topMargin
                                Layout.bottomMargin: backgroundImage.Style.layout.bottomMargin
                                Layout.leftMargin: backgroundImage.Style.layout.leftMargin
                                Layout.rightMargin: backgroundImage.Style.layout.rightMargin
                                Layout.preferredWidth: backgroundImage.Style.layout.preferredWidth > 0 ?
                                                       backgroundImage.Style.layout.preferredWidth : width
                                Layout.preferredHeight: backgroundImage.Style.layout.preferredHeight > 0 ?
                                                        backgroundImage.Style.layout.preferredHeight : height
                                Layout.alignment: Qt.AlignRight | Qt.AlignTop
                                antialiasing: true
                                source: Style.parameter("icon.styledCardInfoBackground")
                                fillMode: Image.PreserveAspectFit
                                Component.onCompleted: mainWindow.scaleImage(this)
                            }
                        }
                    }
                }

                contentItem: ColumnLayout {
                    BasicLabel {
                        Style.class: "styledCardDelegateName"
                        Layout.alignment: Qt.AlignLeft | Qt.AlignTop
                        Layout.preferredWidth: 184
                        Layout.preferredHeight: 20
                        text: "№ " + object.card["number"]
                        elide: Text.ElideRight
                    }
                    ColumnLayout {
                        spacing: 2
                        BasicLabel {
                            visible: styledCard.showStatus
                            Style.class: "styledCardDelegateStatusTitle"
                            Tr { code: "positionCardStatus"; defaultMessage: "Статус" }
                        }
                        BasicLabel {
                            visible: styledCard.showStatus
                            Style.class: "styledCardDelegateStatus"
                            text: styledCard.showStatus ? object.extendedOptions["loyaltyStatus"] : ""
                        }
                        BasicLabel {
                            Style.class: "styledCardDelegateBalanceTitle"
                            Tr { code: "positionCardBalance"; defaultMessage: "Баланс" }
                        }
                        BasicLabel {
                            Style.class: "styledCardDelegateBalance"
                            text: Utils.formatMoneyItem(object.bonusBalance)
                        }
                    }
                }
            }
            // Тень для компонента "стилизованного" отображения информации о карте
            DropShadow {
                anchors.fill: styledCard
                visible: Style.parameter("dropShadow") === "true"
                horizontalOffset: 2
                verticalOffset: 2
                cached: true
                samples: 3
                color: Style.parameter("color.shadowSoft")
                source: styledCard
            }
        }
        ColumnLayout {
            Layout.fillWidth: true
            Layout.alignment: Qt.AlignCenter | Qt.AlignLeft
            BasicLabel {
                Layout.preferredWidth: 190
                Style.class: "cardDelegateClientTitle"
                Tr { code: "positionClientName"; defaultMessage: "Клиент" }
            }
            BasicLabel {
                Layout.preferredWidth: 190
                Style.class: "cardDelegateClientValue"
                text: object.card["client"] && object.card["client"]["name"].length > 0
                      ? object.card["client"]["name"] : " - "
            }
            BasicLabel {
                Layout.preferredWidth: 190
                Style.class: "cardDelegatePhoneTitle"
                Tr { code: "positionClientPhone"; defaultMessage: "Телефон" }
            }
            BasicLabel {
                Layout.preferredWidth: 190
                Style.class: "cardDelegatePhoneValue"
                text: object.card["client"] && object.card["client"]["phoneNumber"].length > 0
                      ? object.card["client"]["phoneNumber"] : " - "
            }
        }
    }
}
